``pants.stream``
****************

.. automodule:: pants.stream


``Stream``
==========

.. autoclass:: Stream
    :members: startSSL, connect, write, write_file, write_packed, flush, close, read_delimiter, buffer_size, remote_address, local_address, on_ssl_handshake, on_connect, on_read, on_write, on_close, on_ssl_handshake_error, on_connect_error, on_overflow_error, on_ssl_error, on_error

